.. image:: https://travis-ci.org/asphalt-framework/asphalt-redis.svg?branch=master
  :target: https://travis-ci.org/asphalt-framework/asphalt-redis
  :alt: Build Status
.. image:: https://coveralls.io/repos/github/asphalt-framework/asphalt-redis/badge.svg?branch=master
  :target: https://coveralls.io/github/asphalt-framework/asphalt-redis?branch=master
  :alt: Code Coverage

This Asphalt framework component provides connectivity to Redis_ database servers.

It is a wrapper for the aioredis_ library.

.. _Redis: http://redis.io/
.. _aioredis: https://github.com/aio-libs/aioredis

Project links
-------------

* `Documentation <http://asphalt-redis.readthedocs.org/en/latest/>`_
* `Help and support <https://github.com/asphalt-framework/asphalt/wiki/Help-and-support>`_
* `Source code <https://github.com/asphalt-framework/asphalt-redis>`_
* `Issue tracker <https://github.com/asphalt-framework/asphalt-redis/issues>`_
